/****************************************************************************
 * @file     M0A23OCClk.c
 * @version  V1.09.0002
 * @Date     Wed Jul 03 2024 21:20:47 GMT+0800 (中国标准时间)
 * @brief    NuMicro generated code file
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2013-2024 Nuvoton Technology Corp. All rights reserved.
*****************************************************************************/

/********************
MCU:M0A23OC1AC(SSOP20)
Base Clocks:
HXT:20MHz
HCLK:20MHz
PCLK0:20MHz
PCLK1:10MHz
Enabled-Module Frequencies:
CAN0=Bus Clock(PCLK0):20MHz
CRC=Bus Clock(HCLK):20MHz
HDIV=Bus Clock(HCLK):20MHz
ISP=Bus Clock(HCLK):20MHz
PWM0=Bus Clock(PCLK0):20MHz
UART0=Bus Clock(PCLK0):20MHz/Engine Clock:20MHz
UART1=Bus Clock(PCLK1):10MHz/Engine Clock:10MHz
USCI0=Bus Clock(PCLK0):20MHz
********************/

#include "NuMicro.h"

/*----------------------------------------------------------------------------
  Define HXT clock.
  Please locate and modify the real one in your project.
  Otherwise, the project may fail to build.
 *----------------------------------------------------------------------------*/
#define __HXT         (20000000UL)  /*!< High Speed External Crystal Clock Frequency */

/*
 * @brief This function updates clock registers to fulfill the configuration
 * @param None
 * @return None
 */
void M0A23OC_SYS_Init(void)
{
    /*---------------------------------------------------------------------------------------------------------*/
    /* Init System Clock                                                                                       */
    /*---------------------------------------------------------------------------------------------------------*/
    //CLK->PWRCTL   = (CLK->PWRCTL   & ~(0xFF0000FFUL)) | 0xB9010011UL;
    //CLK->AHBCLK   = (CLK->AHBCLK   & ~(0x00000096UL)) | 0x00000094UL;
    //CLK->APBCLK0  = (CLK->APBCLK0  & ~(0x110300FDUL)) | 0x01030000UL;
    //CLK->APBCLK1  = (CLK->APBCLK1  & ~(0x00011300UL)) | 0x00010100UL;
    //CLK->CLKSEL0  = (CLK->CLKSEL0  & ~(0x0000003FUL)) | 0x00000038UL;
    //CLK->CLKSEL1  = (CLK->CLKSEL1  & ~(0x7777777FUL)) | 0x4477770BUL;
    //CLK->CLKSEL2  = (CLK->CLKSEL2  & ~(0x00300000UL)) | 0x0020032BUL;
    //CLK->CLKDIV0  = (CLK->CLKDIV0  & ~(0x00FFFF0FUL)) | 0x00000000UL;
    //CLK->PCLKDIV  = (CLK->PCLKDIV  & ~(0x00000077UL)) | 0x00000010UL;
    //CLK->CLKOCTL  = (CLK->CLKOCTL  & ~(0x0000003FUL)) | 0x00000000UL;
    //CLK->CLKDCTL  = (CLK->CLKDCTL  & ~(0x00033030UL)) | 0x00000000UL;
    //SysTick->CTRL = (SysTick->CTRL & ~(0x00010007UL)) | 0x00000000UL;

    /* Unlock protected registers */
    SYS_UnlockReg();

    /* If the macros do not exist in your project, please refer to the related clk.h in Header folder of the tool package */
    /* Set HCLK clock */
    CLK_SetHCLK(CLK_CLKSEL0_HCLKSEL_HXT, CLK_CLKDIV0_HCLK(1));

    /* Set PCLK-related clock */
    CLK->PCLKDIV = (CLK_PCLKDIV_APB0DIV_DIV1 | CLK_PCLKDIV_APB1DIV_DIV1);

    /* Enable IP clock */
    CLK_EnableModuleClock(CAN0_MODULE);
    CLK_EnableModuleClock(CRC_MODULE);
    CLK_EnableModuleClock(HDIV_MODULE);
    CLK_EnableModuleClock(ISP_MODULE);
    CLK_EnableModuleClock(PWM0_MODULE);
    CLK_EnableModuleClock(UART0_MODULE);
    CLK_EnableModuleClock(UART1_MODULE);
    CLK_EnableModuleClock(USCI0_MODULE);

    /* Set IP clock */
    CLK_SetModuleClock(UART0_MODULE, CLK_CLKSEL1_UART0SEL_PCLK0, CLK_CLKDIV0_UART0(1));
    CLK_SetModuleClock(UART1_MODULE, CLK_CLKSEL1_UART1SEL_PCLK1, CLK_CLKDIV0_UART1(1));

    /* Update System Core Clock */
    /* User can use SystemCoreClockUpdate() to calculate SystemCoreClock. */
    SystemCoreClockUpdate();

    /* Lock protected registers */
    SYS_LockReg();
    
    return;
}

/*** (C) COPYRIGHT 2013-2024 Nuvoton Technology Corp. ***/
